==> ejc-guarantee-impl-3.0.0-20230815.101341-44-sources.jar: com/ejianc/business/guarantee/relieve/bean/ContractRelieveEntity.java <==
package com.ejianc.business.guarantee.relieve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_relieve")
public class ContractRelieveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="relieve_remark")
    private String relieveRemark; // 备注
    @TableField(value="premium_mny")
    private BigDecimal premiumMny; // 保费金额
    @TableField(value="premium_tax_mny")
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    @TableField(value="contract_id")
    private Long contractId; // 担保合同id
    @TableField(value = "relieve_date")
    private Date relieveDate;//解保日期
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value = "relieve_name")
    private String relieveName;//解保名称
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Date getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(Date relieveDate) {
        this.relieveDate = relieveDate;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRelieveName() {
        return relieveName;
    }

    public void setRelieveName(String relieveName) {
        this.relieveName = relieveName;
    }
}

==> ejc-guarantee-impl-3.0.0-20240813.091232-71-sources.jar: com/ejianc/business/guarantee/relieve/bean/ContractRelieveEntity.java <==
package com.ejianc.business.guarantee.relieve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 担保合同解保
 * 
 * @author generator
 * 
 */
 @TableName("ejc_guarantee_contract_relieve")
public class ContractRelieveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="relieve_remark")
    private String relieveRemark; // 备注
    @TableField(value="premium_mny")
    private BigDecimal premiumMny; // 保费金额
    @TableField(value="premium_tax_mny")
    private BigDecimal premiumTaxMny; // 保费金额(含税)
    @TableField(value="contract_id")
    private Long contractId; // 担保合同id
    @TableField(value = "relieve_date")
    private Date relieveDate;//解保日期
    @TableField(value="contract_name")
    private String contractName; // 合同名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value = "relieve_name")
    private String relieveName;//解保名称
    @TableField(value = "approve_date")
    private Date approveDate; //审批通过时间

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    public String getRelieveRemark() {
        return relieveRemark;
    }

    public void setRelieveRemark(String relieveRemark) {
        this.relieveRemark = relieveRemark;
    }

    public BigDecimal getPremiumMny() {
        return premiumMny;
    }

    public void setPremiumMny(BigDecimal premiumMny) {
        this.premiumMny = premiumMny;
    }
    public BigDecimal getPremiumTaxMny() {
        return premiumTaxMny;
    }

    public void setPremiumTaxMny(BigDecimal premiumTaxMny) {
        this.premiumTaxMny = premiumTaxMny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Date getRelieveDate() {
        return relieveDate;
    }

    public void setRelieveDate(Date relieveDate) {
        this.relieveDate = relieveDate;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getRelieveName() {
        return relieveName;
    }

    public void setRelieveName(String relieveName) {
        this.relieveName = relieveName;
    }

    public Date getApproveDate() {
        return approveDate;
    }

    public void setApproveDate(Date approveDate) {
        this.approveDate = approveDate;
    }
}
